@@ -208,7 +208,7 @@ impl SubmitRunRequest {
             operating_system: get_os(),
             build_mode: "Release".to_owned(),
             client: client.to_string(),
-            validation: validation.replace("=", ""),
+            validation: validation.replace('=', ""),
             is_replay: run.block.is_replay,
             prohibited_mods: run.block.prohibited_mods,
             game_states: states,
@@ -261,14 +261,13 @@ pub async fn submit<T: ToString, K: ToString>(
 
 pub mod crypto_encoder {
     use std::num::NonZeroU32;
-    use aes::Aes128;
-    use block_modes::{BlockMode, Cbc};
-    use block_modes::block_padding::Pkcs7;
+    use aes::cipher::{block_padding::Pkcs7, BlockEncryptMut};
     use ring::pbkdf2;
     use base32::Alphabet::RFC4648;
     use anyhow::Result;
+    use aes::cipher::KeyIvInit;
 
-    type Aes128Cbc = Cbc<Aes128, Pkcs7>;
+    type Aes128CbcEnc = cbc::Encryptor<aes::Aes128>;
 
     pub fn encrypt_and_encode(plain: String, password: String, salt: String, iv: String) -> Result<String> {
         let password = &password;
@@ -278,16 +277,22 @@ pub mod crypto_encoder {
         pbkdf2::derive(
             pbkdf2::PBKDF2_HMAC_SHA1,
             n_iter,
-            &salt,
+            salt,
             password.as_bytes(),
             &mut pbkdf2_hash,
         );
         let plain = plain.as_bytes();
-        let cipher = Aes128Cbc::new_from_slices(&pbkdf2_hash, &iv.as_bytes())?;
         let mut buffer = [0_u8; 1000]; // big buffer
+        let cipher = match Aes128CbcEnc::new_from_slices(&pbkdf2_hash, iv.as_bytes()) {
+            Ok(v) => Ok(v),
+            Err(_) => Err(anyhow::anyhow!("Cipher Error")),
+        }?;
         let pos = plain.len();
         buffer[..pos].copy_from_slice(plain);
-        let ciphertext = cipher.encrypt(&mut buffer, pos)?;
+        let ciphertext = match cipher.encrypt_padded_mut::<Pkcs7>(&mut buffer, pos) {
+            Ok(v) => Ok(v),
+            Err(_e) => Err(anyhow::anyhow!("Ciphertext Err")),
+        }?;
         Ok(base32::encode(RFC4648 { padding: true }, ciphertext))
     }
 }
